aboutsummaryrefslogtreecommitdiffstats
path: root/core.c
diff options
context:
space:
mode:
authorMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-09-21 17:25:31 +1000
committerMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-10-26 17:27:34 +1100
commitd20d3b185bd84889a1e54b755a8198200c31bc7d (patch)
tree9ca838b320d031fe2cff39e9875e757fc37519ae /core.c
parentc032639678c494710f685612acffeae9b0f603f3 (diff)
Refactor top-level AVIRT API to be avirt_<subject>_<action>
This makes for a more organized function/variable naming convention Signed-off-by: Mark Farrugia <mark.farrugia@fiberdyne.com.au>
Diffstat (limited to 'core.c')
-rw-r--r--core.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/core.c b/core.c
index c9e8d25..e1afce8 100644
--- a/core.c
+++ b/core.c
@@ -343,11 +343,11 @@ static void destroy_avirt_audiopath_obj(struct avirt_audiopath_obj *p)
}
/**
* avirt_get_audiopath - retrieves the Audio Path by its UID
* @uid: Unique ID for the Audio Path
* @return: Corresponding Audio Path
*/
-struct avirt_audiopath *avirt_get_audiopath(const char *uid)
+struct avirt_audiopath *avirt_audiopath_get(const char *uid)
{
struct avirt_audiopath_obj *ap_obj;
list_for_each_entry (ap_obj, &audiopath_list, list) {
@@ -360,12 +360,12 @@ struct avirt_audiopath *avirt_get_audiopath(const char *uid)
}
/**
* avirt_register_audiopath - register Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be registered
* @core: ALSA virtual driver core info
* @return: 0 on success or error code otherwise
*/
-int avirt_register_audiopath(struct avirt_audiopath *audiopath,
+int avirt_audiopath_register(struct avirt_audiopath *audiopath,
struct avirt_coreinfo **info)
{
struct avirt_audiopath_obj *audiopath_obj;
@@ -392,14 +392,14 @@ int avirt_register_audiopath(struct avirt_audiopath *audiopath,
return 0;
}
-EXPORT_SYMBOL_GPL(avirt_register_audiopath);
+EXPORT_SYMBOL_GPL(avirt_audiopath_register);
/**
* avirt_deregister_audiopath - deregister Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be deregistered
* @return: 0 on success or error code otherwise
*/
-int avirt_deregister_audiopath(struct avirt_audiopath *audiopath)
+int avirt_audiopath_deregister(struct avirt_audiopath *audiopath)
{
struct avirt_audiopath_obj *audiopath_obj;
@@ -421,7 +421,7 @@ int avirt_deregister_audiopath(struct avirt_audiopath *audiopath)
return 0;
}
-EXPORT_SYMBOL_GPL(avirt_deregister_audiopath);
+EXPORT_SYMBOL_GPL(avirt_audiopath_deregister);
/**
* avirt_unregister_all - Unregister the platform device driver
@@ -343,11 +343,11 @@ static void destroy_avirt_audiopath_obj(struct avirt_audiopath_obj *p)
}
/**
- * avirt_get_audiopath - retrieves the Audio Path by its UID
+ * avirt_audiopath_get - retrieves the Audio Path by its UID
* @uid: Unique ID for the Audio Path
* @return: Corresponding Audio Path
@@ -360,12 +360,12 @@ struct avirt_audiopath *avirt_get_audiopath(const char *uid)
}
/**
- * avirt_register_audiopath - register Audio Path with ALSA virtual driver
+ * avirt_audiopath_register - register Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be registered
* @core: ALSA virtual driver core info
@@ -392,14 +392,14 @@ int avirt_register_audiopath(struct avirt_audiopath *audiopath,
/**
- * avirt_deregister_audiopath - deregister Audio Path with ALSA virtual driver
+ * avirt_audiopath_deregister - deregister Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be deregistered
* @return: 0 on success or error code otherwise